@@ -5,10 +5,21 @@
 echo "Warning: This script will run configure for you -- if you need to pass"
 echo "  arguments to configure, please give them as arguments to this script."
 
+srcdir=`dirname $0`
+test -z "$srcdir" && srcdir=.
+
+THEDIR="`pwd`"
+cd $srcdir
+
 aclocal
+autoheader
+libtoolize --automake
 automake --add-missing
 autoconf
-automake --add-missing
-configure $*
+automake
+
+cd $THEDIR
+
+$srcdir/configure $*
 
 exit 0
